#!/usr/bin/python
# -*- coding: UTF-8 -*-


import os
import re


class CpuProbe(object):

    _data = {
        'name': "Unknown",
        'frequency': "Unknown",
        'current_frequency': [],
        'number_of_cpu': -1,
        'temperature': 0,
        }

    def __init__(self):
        self.refresh()

    def refresh(self):
        ## CPUINFO
        self._data['current_frequency'] = []
        if os.path.isfile("/proc/cpuinfo"):
            file_cpuinfo = open("/proc/cpuinfo", "r")
            for line in file_cpuinfo:
                # name, frequency
                if re.match(r"^model name\s*:\s*(.+)\s*@\s+([0-9.]+(G|M)Hz)$", line):
                    self._data['name'] = re.match(r"^model name\s*:\s*(.+)\s*@\s+([0-9.]+(G|M)Hz)$", line).group(1).strip()
                    self._data['frequency'] = re.match(r"^model name\s*:\s*(.+)\s*@\s+([0-9.]+(G|M)Hz)$", line).group(2)
                # current_frequency
                elif re.match(r"^cpu MHz\s*:\s*([0-9.]+)$", line):
                    self._data['current_frequency'].append("%sMHz" % re.match(r"^cpu MHz\s*:\s*([0-9.]+)$", line).group(1).split('.')[0])
                # number_of_cpu (including HyperTheading)
                elif re.match(r"^processor\s*:\s*([0-9]+)$", line):
                    self._data['number_of_cpu'] = int(re.match(r"^processor\s*:\s*([0-9]+)$", line).group(1)) + 1
            file_cpuinfo.close()

            ## Temperature
            # eeePC 701
            if os.path.isfile("/proc/acpi/thermal_zone/TZ00/temperature"):
                file_temp = open("/proc/acpi/thermal_zone/TZ00/temperature", "r")
                for line in file_temp:
                    if re.match(r"^temperature\s*:\s*([0-9]+)\s*C$", line):
                        self._data['temperature'] = int(re.match(r"^temperature\s*:\s*([0-9]+)\s*C$", line).group(1))

    def __getattr__(self, attr):
        if attr in self._data:
            return self._data[attr]
        else:
            return None


if __name__ == "__main__":
    cpu = CpuProbe()
    from pprint import pprint
    pprint(cpu._data)
