#!/usr/bin/python
# -*- coding: UTF-8 -*-


import os
import re


class SystemProbe(object):

    _data = {
            'hostname': "Unknown",
            'ostype': "GNU/Linux",
            'os': "Unknown",
            'loadavg': [0.0, 0.0, 0.0],
            'uptime': "",
            'uptimestr': "",
        }

    def __init__(self):
        self.refresh()

    def refresh(self):
        ## HOSTNAME
        if os.path.isfile("/etc/hostname"):
            file_hostname = open("/etc/hostname" ,"r")
            self._data['hostname'] = file_hostname.read().strip();
            file_hostname.close()
        ## OS
        if os.path.isfile("/etc/issue"):
            file_issue = open("/etc/issue", "r")
            self._data['os'] = file_issue.read().replace("\\n", "").replace("\\l", "").strip()
            file_issue.close()
        ## LOADAVG
        if os.path.isfile("/proc/loadavg"):
            file_loadavg = open("/proc/loadavg", "r")
            for line in file_loadavg:
                if re.match(r"^([0-9.]+)\s+([0-9.]+)\s+([0-9.]+)\s+.*$", line):
                    for i in range(3):
                        self._data['loadavg'][i] = float(re.match(r"^([0-9.]+)\s+([0-9.]+)\s+([0-9.]+)\s+.*$", line).group(i+1))
            file_loadavg.close()
        ## UPTIME
        if os.path.isfile("/proc/uptime"):
            file_uptime = open("/proc/uptime", "r")
            self._data['uptime'] = int(float(file_uptime.read().split(" ")[0]))
            # convert
            timesec = self._data['uptime']
            seconds, minutes, hours, days = 0, 0, 0, 0
            seconds = timesec % 60
            timesec /= 60
            minutes = timesec % 60
            timesec /= 60
            hours = timesec % 60 % 24
            days = timesec / 24
            self._data['uptimestr'] = ""
            if days > 1: self._data['uptimestr'] += "%i days, " % days
            elif days == 1: self._data['uptimestr'] += "%i day, " % days
            self._data['uptimestr'] += "%02i:%02i:%02i" % (hours, minutes, seconds)


    def __getattr__(self, attr):
        if attr in self._data:
            return self._data[attr]
        else:
            return None


if __name__ == "__main__":
    system = SystemProbe()
    from pprint import pprint
    pprint(system._data)
